#
# spec file for package python-Cython
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Cython
Version:        0.19.2
Release:        44.1
Url:            http://www.cython.org
Summary:        The Cython compiler for writing C extensions for the Python language
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/C/Cython/Cython-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-devel
Provides:       python-cython = %{version}
Obsoletes:      python-cython < %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
The Cython language makes writing C extensions for the Python language as
easy as Python itself.  Cython is a source code translator based on the
well-known Pyrex, but supports more cutting edge functionality and
optimizations.

The Cython language is very close to the Python language (and most Python
code is also valid Cython code), but Cython additionally supports calling C
functions and declaring C types on variables and class attributes. This
allows the compiler to generate very efficient C code from Cython code.

This makes Cython the ideal language for writing glue code for external C
libraries, and for fast C modules that speed up the execution of Python
code.

%prep
%setup -q -n Cython-%{version}
sed -i "s|^#!.*||" Cython/Debugger/{libpython,Cygdb}.py cython.py # Fix non-executable scripts
sed -i "s|\r||" Demos/callback/{README.txt,cheesefinder.h} Demos/embed/Makefile.{unix,msc.static} Doc/primes.c # Fix EOL encoding
mv bin/cython bin/cython-%{py_ver}
mv bin/cygdb bin/cygdb-%{py_ver}
sed -i "s|bin/cython|bin/cython-%{py_ver}|" setup.py
sed -i "s|bin/cygdb|bin/cygdb-%{py_ver}|" setup.py

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
ln -s  %{_bindir}/cython-%{py_ver} %{buildroot}%{_bindir}/cython
ln -s  %{_bindir}/cygdb-%{py_ver} %{buildroot}%{_bindir}/cygdb
%fdupes -s %{buildroot}%{python_sitearch} %{buildroot}%{_docdir}

%pre
# Since /usr/bin/cython and /usr/bin/cygdb became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[[ ! -L %{_bindir}/cygdb ]] && rm -f %{_bindir}/cygdb
[[ ! -L %{_bindir}/cython ]] && rm -f %{_bindir}/cython
exit 0

%post
update-alternatives \
   --install %{_bindir}/cython cython %{_bindir}/cython-%{py_ver} 30 \
   --slave %{_bindir}/cygdb cygdb %{_bindir}/cygdb-%{py_ver}

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove cython %{_bindir}/cython-%{py_ver}
fi

# Disabled testsuite as it takes a long time:
#%%check
#python runtests.py

%files
%defattr(-,root,root,-)
%doc COPYING.txt LICENSE.txt README.txt ToDo.txt USAGE.txt Doc Demos
%ghost %{_bindir}/cygdb
%{_bindir}/cygdb-%{py_ver}
%ghost %{_bindir}/cython
%{_bindir}/cython-%{py_ver}
%{python_sitearch}/Cython/
%{python_sitearch}/Cython-%{version}-py%{py_ver}.egg-info
%{python_sitearch}/cython.py*
%{python_sitearch}/pyximport/

%changelog
* Mon Oct 21 2013 dmueller@suse.com
- update to 0.19.2:
  * Some standard declarations were fixed or updated, including the previously
    incorrect declaration of ``PyBuffer_FillInfo()`` and some missing bits in
    ``libc.math``.
  * Heap allocated subtypes of ``type`` used the wrong base type struct at the
    C level.
  * Calling the unbound method dict.keys/value/items() in dict subtypes could
    call the bound object method instead of the unbound supertype method.
  * "yield" wasn't supported in "return" value expressions.
  * Using the "bint" type in memory views lead to unexpected results.
    It is now an error.
  * Assignments to global/closure variables could catch them in an illegal state
    while deallocating the old value.
* Fri Oct 11 2013 p.drouand@gmail.com
- Implement update-alternatives
* Mon May 13 2013 dmueller@suse.com
- update to 0.19.1:
  * Completely empty C-API structs for extension type slots (protocols like
  number/mapping/sequence) are no longer generated into the C code.
  * Docstrings that directly follow a public/readonly attribute declaration
  in a cdef class will be used as docstring of the auto-generated property.
  This fixes ticket 206.
  * The automatic signature documentation tries to preserve more semantics
  of default arguments and argument types.  Specifically, ``bint`` arguments
  now appear as type ``bool``.
  * A warning is emitted when negative literal indices are found inside of
  a code section that disables ``wraparound`` handling.  This helps with
  fixing invalid code that might fail in the face of future compiler
  optimisations.
  * Constant folding for boolean expressions (and/or) was improved.
  * Added a build_dir option to cythonize() which allows one to place
  the generated .c files outside the source tree.
* Mon Apr 29 2013 dmueller@suse.com
- Update to version 0.19:
  + Please see http://wiki.cython.org/ReleaseNotes-0.19
* Wed Mar 27 2013 speilicke@suse.com
- Update to version 0.18:
  + Please see http://wiki.cython.org/ReleaseNotes-0.18
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 0.17.2:
  + Please see http://wiki.cython.org/ReleaseNotes-0.17.2
- Drop excessive macro usage
- No need for "-fno-strict-aliasing" anymore
- One rpmlintrc is enough
* Fri May 25 2012 toddrme2178@gmail.com
- Fix .py/.pyc issues
* Fri May 18 2012 toddrme2178@gmail.com
- Add python 3 package
- Clean up spec file formatting
- Remove setbadness from rplintrc files
* Mon Apr 23 2012 vdziewiecki@suse.com
-Update to 0.16:
  http://wiki.cython.org/ReleaseNotes-0.16
* Wed Feb 29 2012 pascal.bleser@opensuse.org
- add rpmlintrc to mask false positives
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 0.15.1:
  * Please see http://wiki.cython.org/ReleaseNotes-0.15.1
* Tue Sep  6 2011 saschpe@suse.de
- Add Provides/Obsoletes for python-cython
* Fri Sep  2 2011 saschpe@suse.de
- Fixed a typo
- Removed testsuite again, fixes SLE build
* Fri Sep  2 2011 saschpe@suse.de
- Update to version 0.15:
  * For loop docs fix and pointer iteration.
  * Pure decorators now implemented.
  * fix bug #707: optimised dict iteration over non-trivial expressions fail...
  * optimise object.pop() for sets
  * Py2.4 fix: PySet_Pop() appeared in Py2.5
  * Py3.3 test fix
  * Support module level control flow and Entry-level error on uninitialized
- Spec file cleanup:
  - Fixed wrong EOL encodings and non-excutable scripts
  - Set license to Apache-2.0
  - Run testsuite
* Wed Apr 20 2011 prusnak@opensuse.org
- updated to 0.14.1
  - changes too numerous to list, see the following for more details:
  * http://wiki.cython.org/ReleaseNotes-0.13
  * http://wiki.cython.org/ReleaseNotes-0.14
  * http://wiki.cython.org/ReleaseNotes-0.14.1
* Sun Jun  6 2010 dimstar@opensuse.org
- Use renewed python-macros, also for compatibility with other
  build targets.
* Sun Jun  6 2010 dimstar@opensuse.org
- Initial package of Cython 0.12.1
